/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.api.deployment.archive;

import org.jvnet.hk2.annotations.Contract;

/**
 * Composite handlers are just like any other ArchiveHandler except they
 * get a chance at looking at the archive before the archive handlers do
 *
 * The main reason for this tag interface is that some archive handlers might
 * be tricked into thinking a composite archive is theirs when in fact they only
 * own a part of it.
 *
 * For instance, take a war file inside an ear file. and asssume that the war file
 * contains some .jsp files. The archive handler responsible for handling the war
 * file could be fooled into thinking the ear file is a war file since it contains
 * jsp files, yet in reality, it only owns one of the sub archive bundled inside
 * the composite ear file.
 *
 * @author Jerome Dochez 
 */
@Contract
public interface CompositeHandler extends ArchiveHandler {

    public boolean accept(ReadableArchive source, String entryName);
    
}
